@@ -33,9 +33,10 @@
 #  define KTPLOGGER_DEPRECATED_NO_EXPORT KTPLOGGER_NO_EXPORT KTPLOGGER_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define KTPLOGGER_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef KTPLOGGER_NO_DEPRECATED
+#    define KTPLOGGER_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
